defmodule DecentralisedBookIndexWeb.AuthorLive.Show do
  use DecentralisedBookIndexWeb, :live_view

  @impl true
  def render(assigns) do
    ~H"""
    <.header>
      Author {@author.id}
      <:subtitle>This is a author record from your database.</:subtitle>

      <:actions>
        <.link navigate={~p"/authors/#{@author}/edit"}>
          <.button>Edit author</.button>
        </.link>
      </:actions>
    </.header>

    <.list>
      <:item title="Id">{@author.id}</:item>

      <:item title="Name">{@author.name}</:item>

      <:item title="Description">{@author.description}</:item>

      <:item title="Avatar url">{@author.avatar_url}</:item>
    </.list>

    <.back navigate={~p"/authors"}>Back to authors</.back>
    """
  end

  @impl true
  def mount(_params, _session, socket) do
    {:ok, socket}
  end

  @impl true
  def handle_params(%{"id" => id}, _, socket) do
    {:noreply,
     socket
     |> assign(:page_title, page_title(socket.assigns.live_action))
     |> assign(
       :author,
       Ash.get!(DecentralisedBookIndex.Metadata.Author, id, actor: socket.assigns.current_user)
     )}
  end

  defp page_title(:show), do: "Show Author"
  defp page_title(:edit), do: "Edit Author"
end
