defmodule DecentralisedBookIndexWeb.PublisherLive.Show do
  use DecentralisedBookIndexWeb, :live_view

  @impl true
  def render(assigns) do
    ~H"""
    <.header>
      Publisher {@publisher.id}
      <:subtitle>This is a publisher record from your database.</:subtitle>

      <:actions>
        <.link patch={~p"/publishers/#{@publisher}/show/edit"} phx-click={JS.push_focus()}>
          <.button>Edit publisher</.button>
        </.link>
      </:actions>
    </.header>

    <.list>
      <:item title="Id">{@publisher.id}</:item>

      <:item title="Name">{@publisher.name}</:item>
    </.list>

    <.back navigate={~p"/publishers"}>Back to publishers</.back>

    <.modal
      :if={@live_action == :edit}
      id="publisher-modal"
      show
      on_cancel={JS.patch(~p"/publishers/#{@publisher}")}
    >
      <.live_component
        module={DecentralisedBookIndexWeb.PublisherLive.FormComponent}
        id={@publisher.id}
        title={@page_title}
        action={@live_action}
        current_user={@current_user}
        publisher={@publisher}
        patch={~p"/publishers/#{@publisher}"}
      />
    </.modal>
    """
  end

  @impl true
  def mount(_params, _session, socket) do
    {:ok, socket}
  end

  @impl true
  def handle_params(%{"id" => id}, _, socket) do
    {:noreply,
     socket
     |> assign(:page_title, page_title(socket.assigns.live_action))
     |> assign(
       :publisher,
       Ash.get!(DecentralisedBookIndex.Metadata.Publisher, id, actor: socket.assigns.current_user)
     )}
  end

  defp page_title(:show), do: "Show Publisher"
  defp page_title(:edit), do: "Edit Publisher"
end
